_**International Journal of Sports Physiology and Performance,**_ **2016, 11, 267 -272**
[http://dx.doi.org/10.1123/ijspp.2015-0638](http://dx.doi.org/10.1123/ijspp.2015-0638)
© 2016 Human Kinetics, Inc.

# **Interpreting Power-Force-Velocity Profiles** **for Individualized and Specific Training**

**Jean-Benoît Morin and Pierre Samozino**

INVITED COMMENTARY

Recent studies have brought new insights into the evaluation of power-force-velocity profiles in both ballistic push-offs (eg,
jumps) and sprint movements. These are major physical components of performance in many sports, and the methods the authors
developed and validated are based on data that are now rather simple to obtain in field conditions (eg, body mass, jump height,
sprint times, or velocity). The promising aspect of these approaches is that they allow for more individualized and accurate
evaluation, monitoring, and training practices, the success of which is highly dependent on the correct collection, generation,
and interpretation of athletes’ mechanical outputs. The authors therefore wanted to provide a practical vade mecum to sports
practitioners interested in implementing these power-force-velocity–profiling approaches. After providing a summary of theoretical and practical definitions for the main variables, the authors first detail how vertical profiling can be used to manage ballistic push-off performance, with emphasis on the concept of optimal force–velocity profile and the associated force–velocity
imbalance. Furthermore, they discuss these same concepts with regard to horizontal profiling in the management of sprinting
performance. These sections are illustrated by typical examples from the authors’ practice. Finally, they provide a practical and
operational synthesis and outline future challenges that will help further develop these approaches.

_**Keywords**_ _:_ explosive performance, jump, sprint, team sports, athletics, strength training

One of the main physical performance determinants in sports
such as athletics, rugby, soccer, football, volleyball, and basketball
is the ability to produce high mechanical power output during jumps
and sprint accelerations. \[1,2\] This power output depends on the ability
of athletes’ neuromuscular and osteoarticular systems to generate
high levels of force, apply it with effectiveness onto the environment (ie, supporting ground, ball, projectile), and produce this
force at high contraction velocity. Force and velocity are therefore
considered the underpinning features of mechanical power output
in sport movements. \[3,4\] Although the assessment and long-term
monitoring of these capabilities is paramount for both performance
and rehabilitation processes, such an accurate evaluation has long
been associated with expensive and often laboratory-based technologies. Recently, our research group has presented simple field
methods to compute force, velocity, and power output in jumping \[5\]
and sprinting \[6\] calculated via measurements from widely accessible
and practical devices. Thanks to these methods, all the important
mechanical outputs of jumping and sprinting can be derived from
basic measures of body mass, lower-limb length, jump height, and
distance–time or speed–time measurements only. \[6–8\]
Recently, we had the opportunity to discuss the implementation of these “simple methods” with many sport practitioners, and
we realized that beyond the description presented in the published
papers, it was necessary to detail how to interpret the measurements
for an efficient use in everyday practice. Our aim here is to provide
a practical vade mecum to readers wishing to use power-forcevelocity profiling for more individualized diagnostic and efficient

Morin is with the Laboratory of Human Motricity, Education Sport and
Health, University of Nice Sophia Antipolis, Nice, France. Samozino is
with the Inter-Universitary Laboratory of Human Movement Biology,
University Savoie Mont Blanc, Le Bourget-du-Lac, France. Address author
[correspondence to Jean-Benoît Morin at jean-benoit.morin@unice.fr.](mailto:jean-benoit.morin@unice.fr)

training. The key points of this commentary will be supported by
illustrations of typical data collected in our research, training, or
consultancy practice over the past decade.

## **Definitions**

The power-force-velocity–profiling approach is based on force–
velocity (F–V) and power–velocity relationships characterizing the
maximal mechanical capabilities of the lower limbs’ neuromuscular
system. The definition and the practical interpretation of the main
mechanical variables of interest are presented in Table 1.

## **Vertical Profiling for Ballistic Push-Off** **Performance**

The input measurements necessary to correctly determine vertical
profile \[5,9,10\] are the athlete’s body mass, lower-limb length in fully
extended position, starting height, and jump height (measured under
a spectrum of loading parameters). The latter can now be easily and
accurately measured using simple and accessible devices. \[7,8\] Jump
height should be measured across repeated measurements with at
least 5 additional loads (evenly ranging between 0 kg and the additional load with which the athlete is able to jump about 10 cm), after
which the F–V profile and all other computations can be completed.
Research conclusions show that jumping performance is determined by maximal mechanical power output ( _VTC-Pmax_ ) and the
magnitude of the relative difference between the slope of the linear
F–V relationship ( _Sfv_ ) and _Sfv_ opt for a given individual ( _FVimb_ ). \[9\]
Thus, in practical terms, should a training program be designed to
improve athletes’ ballistic push-off performance (eg, jumps, single
maximal push-offs, change of direction), the focus should be placed
on increasing _VTC-Pmax_ and/or decreasing _FVimb_ . With regard to
athletes displaying significant imbalance in mechanical capacities,

**267**

**Table 1 Definition and Practical Interpretation of the Main Variables of Interest When Using Power-Force-Velocity**
**Profiling in Ballistic Push-Offs (Vertical Profiling) and Sprinting (Horizontal Profiling)**

**Profiling variable** **Definition and computation** **Practical interpretation**

Vertical

_VTC-F0_ (N/kg) Theoretical maximal force production of
the lower limbs as extrapolated from the
linear loaded jump squats’ force–velocity (F–V) relationship; _y_ -intercept of the
linear F–V relationship.

_VTC-V0_ (m/s) Theoretical maximal extension velocity
of the lower limbs as extrapolated from
the linear loaded jump squats’ F–V relationship; _x_ -intercept of the linear F–V
relationship.

_VTC-Pmax_ (W/kg) Maximal mechanical power output,
computed as _Pmax_ = _F0_ × _V0_ /4 or as the
apex of the P–V 2nd-degree polynomial
relationship.

Maximal concentric force output (per unit body mass) that the athlete’s lower
limbs can theoretically produce during ballistic push-off. Determined from
the entire F–V spectrum, it gives more integrative information on force capability than, eg, concentric squat 1-repetition-maximum load.

Maximal extension velocity of the athlete’s lower limbs during ballistic
push-off. Determined from the entire F–V spectrum and very difficult, if not
impossible, to reach and measure experimentally. It also represents the capability to produce force at very high extension velocities.

Maximal power output capability of the athlete’s lower-limb neuromuscular
system (per unit body mass) in the concentric and ballistic extension motion.

S _fv_ Slope of the linear F–V relationship, Index of the athlete’s individual balance between force and velocity capacomputed as _Sfv_ = – _F0_ / _V0_ . bilities. The steeper the slope, the more negative its value, the more “forceoriented” the F–V profile, and vice versa.

_Sfv_ opt For a given push-off distance, body
mass, and _Pmax_, the unique value of _Sfv_
that maximizes jump height. For detailed
computation, see Appendix in Samozino
et al. \[10\]

_FVimb_ (%) Magnitude of the relative difference
between _Sfv_ and _Sfv_ opt for a given individual. Computed as ( _Sfv_ / _Sfvopt_ ) × 100
and expressed in percentage.

Horizontal

_HZT-F0_ (N/kg) Theoretical maximal horizontal force
production as extrapolated from the
linear sprint F–V relationship; _y_ -intercept of the linear F–V relationship.

_HZT-V0_ (m/s) Theoretical maximal running velocity as
extrapolated from the linear sprint F–V
relationship; _x_ -intercept of the linear
F–V relationship.

_HZT-Pmax_ (W/kg) Maximal mechanical power output in the
horizontal direction, computed as _Pmax_
= _F0_ × _V0_ /4, or as the apex of the P–V
2nd-degree polynomial relationship.

_RF_ (%) Ratio of force, computed as the ratio of
the step-averaged horizontal component
of the ground-reaction force to the corresponding resultant force.

The optimal F–V profile that represents the optimal balance, for a given individual, between force and velocity capabilities. For a given maximal power
_Pmax,_ this profile will be associated, ceteris paribus, with the highest ballistic
push-off performance possible for this individual. Training programs should
be designed to both increase _Pmax_ and orient _Sfv_ toward _Sfv_ opt.

Magnitude of the difference between actual and optimal F–V profiles. A value
of 100% means _Sfv_ = _Sfv_ opt, ie, optimized F–V profile. Values above 100%
mean an imbalance with a deficit in velocity, and vice versa. The larger the
difference with the optimal 100% value, the larger the imbalance.

Maximal force output (per unit body mass) in the horizontal direction. Corresponds to the initial push of the athlete onto the ground during sprint acceleration. The higher the value, the higher the sprint-specific horizontal force
production.

Sprint-running maximal velocity capability of the athlete. Slightly higher than
the actual maximal velocity. The theoretical maximal running velocity the
athlete would be able to reach should mechanical resistances (ie, internal and
external) against movement be null. It also represents the capability to produce horizontal force at very high running velocities.

Maximal power-output capability of the athlete in the horizontal direction
(per unit body mass) during sprint acceleration.

Direct measurement of the proportion of the total force production that is
directed in the forward direction of motion, ie, the mechanical effectiveness
of force application of the athlete. The higher the value, the more important
the part of the total force output directed forward.

_RFmax_ (%) Maximal value of _RF_, computed as max- Theoretically maximal effectiveness of force application. Direct measurement
imal value of _RF_ for sprint times >0.3 s. of the proportion of the total force production that is directed in the forward
direction of motion at sprint start.

_DRF_ Rate of decrease in _RF_ with increasing
speed during sprint acceleration, computed as the slope of the linear _RF_ –V
relationship.

Describes the athlete’s capability to limit the inevitable decrease in mechanical effectiveness with increasing speed, ie, an index of the ability to maintain
a net horizontal force production despite increasing running velocity. The
more negative the slope, the faster the loss of effectiveness of force application during acceleration, and vice versa.

**268** **IJSPP Vol. 11, No. 2, 2016**

training programs should prioritize training the lacking mechanical
capability to shift _Sfv_ toward _Sfv_ opt. The main interest of the current
approach is that the diagnostics, and resultant training periodization,
are individualized and easily monitored. Consequently, the ability
to frequently monitor these outputs permits the analysis of changes
in _VTC-Pmax_ and _FVimb_ over time (eg, once every month) and
can assist in the targeted implementation and reimplementation of
efficient and dynamic programming practices. The first case report
(Figure 1) illustrates this with data from 2 athletes with a similar
push-off distance. Although athlete A has a higher _VTC-Pmax,_ his
squat-jump performance is lower because he has an F–V imbalance.
Athlete B has a lower _VTC-Pmax,_ but his profile is almost exactly
equal to his individual optimal profile (only 1% imbalance). The
current approach would suggest, therefore, that athlete A’s training
should prioritize the development of maximal force capabilities to
correct his imbalance and increase _VTC-Pmax_ . Once this goal is

Power-Force-Velocity Profiles and Training **269**

achieved, he may transition into training similar to that of athlete
B, to improve his _VTC-Pmax_ while maintaining his corrected (ie,
optimal) profile.
The second example shows 2 young players from the same
soccer team (French first-league professional club academy U19).
As shown in Figure 2, these players have quite similar _VTC-Pmax_
and _Sfv_ opt values but display opposing _FVimb_ characteristics: Player
A shows a force deficit, whereas player B shows a velocity deficit.
Furthermore, the absolute difference with their respective _Sfv_ opt is
lower in player B than in player A (28% vs 37%). This relatively
smaller _FVimb_ and slightly higher _VTC-Pmax_ in player B explain
his higher squat-jump performance.
With this result in mind, this approach suggests that the most
efficient way to train and improve ballistic push-off performance
in both these players would be an individualized program (indexed
on each player’s _FVimb_ ) that targets the development of different

**Figure 1** — Vertical force–velocity profiles of 2 track and field athletes (body mass for A, 67.2 kg, and B, 82.8 kg; push-off distance for A, 0.34 m, and
B, 0.35 m) obtained from maximal squat jumps (SJ) against additional loads of 0, 10, 20, 30, and 40 kg. Despite a higher _VTC-Pmax_ (maximal mechanical
power output) value, athlete A’s squat-jump performance is lower because his _FVimb_ (magnitude of the relative difference between the slope of the linear
force–velocity relationship \[ _Sfv_ \] and _Sfv_ opt) is greater than for athlete B. For athlete A, the black line indicates the actual profile, and the dashed line, the
optimal profile. Note that athlete B’s profile if almost optimal, and therefore the actual and optimal relationships are confounded in the right panel (gray
line and black dashed line). Abbreviations: _VTC-F0,_ maximal force production of the lower limbs; _VTC-V0,_ maximal extension velocity of the lower limbs.

**Figure 2** — Vertical force–velocity profiles of 2 elite young (under-19) soccer players (body mass for A, 78 kg, and B, 75.5 kg; push-off distance for
A, 0.26 m, and B, 0.28 m) obtained from maximal squat jumps (SJ) against additional loads of 0, 10, 20, 40, and 50 kg. One player has a force deficit
(magnitude of the relative difference between the slope of the linear force–velocity relationship \[ _Sfv_ \] and _Sfv_ opt \[ _FVimb_ \] of 72%), whereas the other has a
velocity deficit ( _FVimb_ of 137%). Player A is a central defender and player B is a goalkeeper. Abbreviation: _VTC-Pmax,_ maximal mechanical power output.

**IJSPP Vol. 11, No. 2, 2016**

**270** Morin and Samozino

capabilities. Our yet-unpublished observations have shown that
such an individually optimized approach is more efficient that a
one-size-fits-all program, identical for those 2 players.
The latter example raises an important question, however, with
regard to the application of improving ballistic push-off performance
in cyclic movements such as sprint running. This particular question
is the main interest when developing forward (sprint) acceleration
and performance characteristics, for instance, in soccer or rugby
players (except for some players like goalkeepers or some specific
sport actions involving jumps), and will be discussed in the following section detailing horizontal profiling for sprint performance.

## **Horizontal Profiling for Sprint Performance**

The inputs that must be measured to determine the horizontal
profile \[6\] are the athlete’s body mass and height and either distance–
time or speed–time running data. The latter can be measured using
a series of timing gates (at least 5 split times, eg, 5, 10, 20, 30,
and 40 m) or a laser or radar device (eg, ~50-Hz Stalker ATSII
radar, Applied Concepts Inc, Plano, TX). Wind speed, ambient
temperature, and pressure must also be known to accurately estimate air-friction force. The entire power-force-velocity profile can
then be computed from the simple modeling of the derivation of
the speed–time curve that leads to horizontal acceleration data.
Likewise, the mechanical effectiveness of force application can be
determined via the linear relationship between ratio of force ( _RF_ )
and running velocity \[11\] (Figure 3). Our research has shown that, in
addition to maximal mechanical power output in the horizontal
direction ( _HZT-Pmax_ ), 100-m performance was related to the ability
to apply high amounts of force in the horizontal direction ( _RF_ and
rate of decrease in _RF_ \[ _DRF_ \] indices). \[11–13\] With regard to shorter
sprints (ie, acceleration-only phases, eg, up to 10–20 m in rugby
or soccer specialists), recent results have shown that the shorter
the distance considered, the higher the relationship between sprint
performance and maximal horizontal force production ( _HZT-F0_ )
(unpublished observations). Thus, in practical terms, if a training
program is designed to improve sprint-acceleration performance,

the focus should be placed on increasing _HZT-Pmax_ by improving
its components ( _HZT-F0_ and maximal running velocity \[ _HZT-V0_ \]).
This could be done by first comparing the relative strengths and
weaknesses in each player’s profile with the rest of the team, and
then programming the training content depending on the distance
over which sprint acceleration should be optimized. As for vertical
profiling, the main value of this approach is that the diagnostic and
subsequent targeted training interventions are individualized, and
frequent monitoring of program-induced changes in _HZT-Pmax_ and
its mechanical determinants can make this program more efficient
and dynamic in terms of adaptation to individual changes over
time. In particular, since _HZT-F0_ and _RF_ are paramount for short
sprint-acceleration performances, coupling the vertical profiling to
the horizontal profiling can help identify the determinants of _HZT-_
_F0_ . Using this approach, we consider _HZT-F0_ to result from the
interaction of the overall strength capability of the athlete at each
lower-limb extension (as assessed by the vertical profile) and his
or her ability to transfer this overall strength level to the specific,
forward sprint motion at the first steps (as evidenced by _RFmax_ ) or
at steps at high velocities (as evidenced by _DRF_ ) (Table 1, Figure 4).
In short, a high _HZT-F0_ can result from high _VTC-Pmax_ and a high
quality of vertical-to-horizontal transfer (ie, good _RFmax_ and _DRF_
values), whereas a low _HZT-F0_ can result from a high _VTC-Pmax_
with a low-quality transfer (poor _RFmax_ and _DRF_ values); vice versa,
a low _VTC-Pmax_ with a high-quality transfer (good _RFmax_ and _DRF_
values); or any possible intermediate combination.
The case report used to illustrate these points shows data from
2 players of an elite rugby union team. Figure 3 shows that the 2
players have similar 20-m times (maximal acceleration from a standing start) and _HZT-Pmax_ values, yet with opposite F–V profiles and
_RF_ -velocity profiles. Indeed, player C has higher horizontal forceproduction capabilities (in the specific context of sprint push-off),
especially at the beginning of the sprint and notably due to a higher
effectiveness of ground-force application (indicated in a higher
_RFmax_ ). However, his _DRF_ is more negative, meaning his higher
initial effectiveness decreases at a greater rate as speed increases
than for player D. This has likely contributed to higher velocity

**Figure 3** — Horizontal force–velocity profiles of 2 elite rugby union players (body mass for C, 108.8 kg, and D, 86.1 kg) obtained from maximal
30-m sprints. Both players reached their maximal running speed before the 30-m mark. Abbreviations: _HZT-Pmax,_ maximal mechanical power output
in the horizontal direction; _DRF,_ rate of decrease in ratio of force with increasing speed during sprint acceleration; _HZT-F0,_ maximal horizontal force
production; _HZT-V0,_ maximal running velocity.

**IJSPP Vol. 11, No. 2, 2016**

Power-Force-Velocity Profiles and Training **271**

**Figure 4** — Decision tree to interpret the force-velocity-power profiles in relationship with ballistic push-off (eg, jumping) and sprinting performances.
These mechanistic relationships are based on both the theoretical features of our models \[5,6,9–13,20\] and some experimental evidence ( \[18,19\] and unpublished
data). In sprinting, the shorter the acceleration distance, the higher the importance of _HZT-F0_ capabilities compared with _HZT-V0,_ and vice versa. Abbreviations: _FVimb,_ magnitude of the relative difference between the slope of the linear force–velocity relationship ( _Sfv_ ) and _Sfv_ opt; _VTC-Pmax,_ maximal
mechanical power output; _HZT-F0,_ maximal horizontal force production; _DRF,_ rate of decrease in the ratio of force with increasing speed during sprint
acceleration; _HZT-V0,_ maximal running velocity; _RFmax,_ maximal ratio of force.

capabilities, which explains the higher _HZT-V0_ of player D. As for
ballistic push-off, we suggest that the training program designed to
improve sprint performance (eg, here 20-m time) in each of these
2 players should target different capabilities. A similar program
given to these players (which is current practice in the majority of
teams, based on our perception) will very likely result in suboptimal adaptations for both of them. In particular, player D’s training
should target as a priority his _HZT-F0_ capabilities. Here, in terms of
injury prevention, this suggests that this player could be given more
strength and horizontal strength work than others and probably less
maximal sprint velocity work. This could directly reduce the risk for
sprinting-related injuries for this player by reducing the total time
he would be exposed to high-speed running. \[14–17\] For this player,
compared with player C (and potentially compared with the average
value of the group/team), _HZT-F0_ should be developed, especially
through increasing _RFmax_ . Adding the previously described vertical profiling to this horizontal profiling could help better determine
whether a lower _HZT-F0_ is due to an overall deficit of lower-limb
strength (as indicated by a low _VTC-Pmax_ ) and/or a deficit in the
transfer of this strength in the specific horizontal push-off motion
(technical capability). Differences in horizontal profiles have been
reported in elite rugby players according to individual player positions \[18\] and in young soccer players. \[19\]

## **Practical Synthesis**

Figure 4 shows a decision tree, with a specific focus on ballistic
push-off and sprint-acceleration performance, which are 2 major
physical determinants in many sports. This figure is designed to help
practitioners use the vertical and horizontal profiling approach to
better detect the strengths and weaknesses in their athletes and design
more-effective training interventions. Vertical profiling will provide
information as to what physical capabilities should be developed
to improve ballistic push-off performance and as to the maximal
levels of force and velocity of the athlete’s neuromuscular system.
Horizontal profiling will provide information as to the specific sprintacceleration motion and as to what underlying physical or technical
feature(s) mainly limit each individual’s sprint performance.

## **Conclusion and Perspectives**

These novel approaches of vertical and horizontal force-velocity-power
profiling have the potential to provide sport practitioners simple, cheap,
yet accurate methods for more individualized monitoring and training
of physical and technical capabilities. These methods can be easily
implemented on a regular basis, since they are based on common and
sport-specific movements (ballistic push-offs and sprint accelerations),
and can therefore be used for long-term monitoring and training processes. Furthermore, they may also be implemented in injury-prevention
and -rehabilitation processes since diagnostic information will assist in
better-designed sprint-related training programs, and clear differences
have been observed between injured and noninjured players. \[20,21\]
The limitations of these approaches have been extensively
discussed, \[5,6,22\] and the main perspective stems from the fact that
these profiling methods give information as to _what_ specific muscle
outputs should be developed, not _how_ this should be done. This
will be the next challenge that we are pleased to undertake: testing
and investigating the most-efficient practical (training) methods to
improve each mechanical determinant of performance and further
extending the current knowledge on this topic \[4\] using the novel
approaches presented here.

**Acknowledgments**

We are forever grateful for the help (and trust) of all the sports practitioners
(coaches, physiotherapists, managers, doctors, researchers, students) who have
helped us develop these approaches over the last 10 years. We also thank all
the athletes, of all levels of performance, who did, do, or will give voluntarily
and enthusiastically their best effort during testing. A special thanks goes to
our friend and colleague Pedro Jimenez-Reyes, for his dedicated work and
help in developing this approach. We gratefully thank Matt Cross and Matt
Brughelli for their careful reading and comments on the revised manuscript.

## **References**

1. Cronin J, Sleivert G. Challenges in understanding the influence of maximal power training on improving athletic performance. _Sports Med_ .
   [2005;35:213–234. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=15730337&dopt=Abstract) [doi:10.2165/00007256-200535030-00003](http://dx.doi.org/10.2165/00007256-200535030-00003)

**IJSPP Vol. 11, No. 2, 2016**

**272** Morin and Samozino

2. Cronin JB, Hansen KT. Strength and power predictors of sports speed.
   _J Strength Cond Res_ [. 2005;19:349–357. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=15903374&dopt=Abstract)

1. Cormie P, McGuigan MR, Newton RU. Developing maximal neuromuscular power: part 1—biological basis of maximal power production. _Sports Med_ [. 2011;41(1):17–38. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=21142282&dopt=Abstract) [doi:10.2165/11537690-](http://dx.doi.org/10.2165/11537690-000000000-00000)
   [000000000-00000](http://dx.doi.org/10.2165/11537690-000000000-00000)

1. Cormie P, McGuigan MR, Newton RU. Developing maximal neuromuscular power: part 2—training considerations for improving
   maximal power production. _Sports Med_ [. 2011;41:125–146. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=21244105&dopt=Abstract)
   [doi:10.2165/11538500-000000000-00000](http://dx.doi.org/10.2165/11538500-000000000-00000)

1. Samozino P, Morin JB, Hintzy F, Belli A. A simple method for measuring force, velocity and power output during squat jump. _J Biomech_ .
   [2008;41:2940–2945. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=18789803&dopt=Abstract) [doi:10.1016/j.jbiomech.2008.07.028](http://dx.doi.org/10.1016/j.jbiomech.2008.07.028)

1. Samozino P, Rabita G, Dorel S, Slawinski J, Peyrot N, Saez de Villarreal E, Morin JB. A simple method for measuring power, force,
   velocity properties, and mechanical effectiveness in sprint running

\[published online ahead of print\]. _Scand J Med Sci Sports_ . 2015;
[doi:10.1111/sms.12490 PubMed](http://dx.doi.org/10.1111/sms.12490)

7. Balsalobre-Fernández C, Glaister M, Lockey RA. The validity and
   reliability of an iPhone app for measuring vertical jump performance.
   _J Sports Sci_ [. 2015;33(15):1574–1579. PubMed doi:10.1080/026404](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=25555023&dopt=Abstract)
   14.2014.996184

1. Stanton R, Kean CO, Scanlan AT. My Jump for vertical jump assessment. _Br J Sports Med_ . 2015; [doi:10.1136/bjsports-2015-094831.](http://dx.doi.org/10.1136/bjsports-2015-094831)
   [PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=26124470&dopt=Abstract)

1. Samozino P, Edouard P, Sangnier S, Brughelli M, Gimenez P, Morin JB.
   Force–velocity profile: imbalance determination and effect on lower limb
   ballistic performance. _Int J Sports Med_ [. 2014;35:505–510. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=24227123&dopt=Abstract)

1. Samozino P, Rejc E, Di Prampero PE, Belli A, Morin JB. Optimal
   force–velocity profile in ballistic movements—altius: citius or fortius?
   _Med Sci Sports Exerc_ [. 2012;44(2):313–322. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=21775909&dopt=Abstract) [doi:10.1249/](http://dx.doi.org/10.1249/MSS.0b013e31822d757a)
   [MSS.0b013e31822d757a](http://dx.doi.org/10.1249/MSS.0b013e31822d757a)

1. Morin JB, Edouard P, Samozino P. Technical ability of force application
   as a determinant factor of sprint performance. _Med Sci Sports Exerc_ .
   [2011;43:1680–1688. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=21364480&dopt=Abstract) [doi:10.1249/MSS.0b013e318216ea37](http://dx.doi.org/10.1249/MSS.0b013e318216ea37)

1. Morin JB, Bourdin M, Edouard P, Peyrot N, Samozino P, Lacour JR.
   Mechanical determinants of 100-m sprint running performance. _Eur_
   _J Appl Physiol_ [. 2012;112:3921–3930. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=22422028&dopt=Abstract) [doi:10.1007/s00421-](http://dx.doi.org/10.1007/s00421-012-2379-8)
   [012-2379-8](http://dx.doi.org/10.1007/s00421-012-2379-8)

1. Rabita G, Dorel S, Slawinski J, et al. Sprint mechanics in world-class
   athletes: a new insight into the limits of human locomotion. _Scand J_
   _Med Sci Sports_ [. 2015;25:583–594. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=25640466&dopt=Abstract) [doi:10.1111/sms.12389](http://dx.doi.org/10.1111/sms.12389)

1. Arnason A, Sigurdsson SB, Gudmundsson A, Holme I, Engebretsen
   L, Bahr R. Physical fitness, injuries, and team performance in soccer.
   _Med Sci Sports Exerc_ [. 2004;36:278–285. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=14767251&dopt=Abstract) [doi:10.1249/01.](http://dx.doi.org/10.1249/01.MSS.0000113478.92945.CA)
   [MSS.0000113478.92945.CA](http://dx.doi.org/10.1249/01.MSS.0000113478.92945.CA)

1. Feddermann-Demont N, Junge A, Edouard P, Branco P, Alonso
   JM. Injuries in 13 international athletics championships between
   2007–2012. _Br J Sports Med_ [. 2014;48:513–522. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=24620039&dopt=Abstract) [doi:10.1136/](http://dx.doi.org/10.1136/bjsports-2013-093087)
   [bjsports-2013-093087](http://dx.doi.org/10.1136/bjsports-2013-093087)

1. Ueblacker P, Mueller-Wohlfahrt HW, Ekstrand J. Epidemiological and clinical outcome comparison of indirect (‘strain’) versus
   direct (‘contusion’) anterior and posterior thigh muscle injuries
   in male elite football players: UEFA Elite League study of 2287
   thigh injuries (2001–2013). _Br J Sports Med_ . 2015; [doi:10.1136/](http://dx.doi.org/10.1136/bjsports-2014-094285)
   [bjsports-2014-094285. PubMed](http://dx.doi.org/10.1136/bjsports-2014-094285)

1. Woods C, Hawkins RD, Maltby S, Hulse M, Thomas A, Hodson A.
   The Football Association Medical Research Programme: an audit of
   injuries in professional football—analysis of hamstring injuries. _Br J_
   _Sports Med_ [. 2004;38:36–41. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=14751943&dopt=Abstract) [doi:10.1136/bjsm.2002.002352](http://dx.doi.org/10.1136/bjsm.2002.002352)

1. Cross MR, Brughelli M, Brown SR, et al. Mechanical properties of
   sprinting in elite rugby union and rugby league. _Int J Sports Physiol_
   _Perform_ [. 2015;10:695–702. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=25310279&dopt=Abstract) [doi:10.1123/ijspp.2014-0151](http://dx.doi.org/10.1123/ijspp.2014-0151)

1. Buchheit M, Samozino P, Glynn JA, et al. Mechanical determinants
   of acceleration and maximal sprinting speed in highly trained young
   soccer players. _J Sports Sci_ [. 2014;32:1906–1913. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=25356503&dopt=Abstract) [doi:10.10](http://dx.doi.org/10.1080/02640414.2014.965191)
   [80/02640414.2014.965191](http://dx.doi.org/10.1080/02640414.2014.965191)

1. Mendiguchia J, Samozino P, Martinez-Ruiz E, et al. Progression of
   mechanical properties during on-field sprint running after returning to
   sports from a hamstring muscle injury in soccer players. _Int J Sports_
   _Med_ [. 2014;35:690–695. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=24424959&dopt=Abstract) [doi:10.1055/s-0033-1363192](http://dx.doi.org/10.1055/s-0033-1363192)

1. Mendiguchia J, Edouard P, Samozino P, et al. Field monitoring
   of sprinting power-force-velocity profile before, during and after
   hamstring injury: 2 case reports. _J Sports Sci_ . 2016;34(6):535–541.
   [PubMed doi:10.1080/02640414.2015.1122207](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=26648237&dopt=Abstract)

1. Samozino P, Morin JB, Hintzy F, Belli A. Jumping ability: a theoretical integrative approach. _J Theor Biol_ [. 2010;264:11–18. PubMed](http://www.ncbi.nlm.nih.gov/entrez/query.fcgi?cmd=Retrieve&db=PubMed&list_uids=20109471&dopt=Abstract)
   [doi:10.1016/j.jtbi.2010.01.021](http://dx.doi.org/10.1016/j.jtbi.2010.01.021)

**IJSPP Vol. 11, No. 2, 2016**
